@@ -11,10 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-__version__ = '0.14.11'
+__version__ = '0.15.0'
 
 
 from . import algebra  # noqa
+from . import augmenters # noqa
 from . import architectures  # noqa
 from . import callbacks  # noqa
 from . import classification_metrics  # noqa
@@ -33,3 +34,4 @@ from . import training_metrics  # noqa
 from . import types  # noqa
 from . import utils  # noqa
 from . import visualization  # noqa
+from . import schedules # noqa
